import click
from covidcharter.service import filter_by_county, plot_data, get_all_counties


@click.command()
@click.option('--county', help='The county or locality to get the graph for')
def graph(county):
    try:
        click.echo('Graphing the data...')
        df = filter_by_county(county)
        plot_data(df)
    except:
        counties = get_all_counties()
        click.echo('Please try again. The covidcharter data chart generator requires a county from the following list: %s'
                   % counties)


if __name__ == '__main__':
    graph()



from distutils.core import setup
setup(
  name = 'covidcharter',
  packages = ['covidcharter'],
  version = '0.1',
  license='MIT',
  description = 'A package for charting covid in Virginia counties',
  author = 'Haley Creech',
  author_email = 'haley.creech@gmail.com',
  url = 'https://github.com/creecherr/virginia-covid-charter',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/creecherr/virginia-covid-charter/archive/v.0.1.tar.gz',
  keywords = ['covid', 'vdh', 'virgnia'],
  install_requires=[
          'matplotlib',
          'pandas',
          'click',
          'requests',
          'urllib3'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Healthcare Industry',
    'Topic :: Multimedia :: Graphics :: Capture',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
  ],
)


import requests
import io
import pandas as pd
import matplotlib.pyplot as plt
import urllib3
urllib3.disable_warnings()


def get_vdh_data():
    #todo make some try/excepts
    endpoint = 'https://www.vdh.virginia.gov/content/uploads/sites/182/2020/03/VDH-COVID-19-PublicUseDataset-Cases.csv'
    response = requests.get(endpoint, verify=False).content
    vdh_covid_df = pd.read_csv(io.StringIO(response.decode('utf-8')))
    return vdh_covid_df


def filter_by_county(county):
    vdh_covid_df = get_vdh_data()
    is_health_distrct = vdh_covid_df["Locality"] == county
    filtered_df = vdh_covid_df[is_health_distrct]
    return filtered_df


def plot_data(df):
    sorted_df = df.sort_values(by=['Total Cases'])
    sorted_df.plot(kind='line', x='Report Date', y='Total Cases')
    plt.show()


def get_all_counties():
    df = get_vdh_data()
    is_report_date = df["Report Date"] == "3/17/2020"
    filtered_df = df[is_report_date]
    counties_list = filtered_df['Locality'].tolist()
    return counties_list


